max6675

package
v0.34.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 15, 2025 License: BSD-3-Clause Imports: 3 Imported by: 0

Documentation

Overview

Datasheet: https://www.analog.com/media/en/technical-documentation/data-sheets/max6675.pdf

Index

Constants

This section is empty.

Variables

var ErrThermocoupleOpen = errors.New("thermocouple input open")

ErrThermocoupleOpen is returned when the thermocouple input is open. i.e. not attached or faulty

Functions

This section is empty.

Types

type Device

type Device struct {
	// contains filtered or unexported fields
}

func NewDevice

func NewDevice(bus drivers.SPI, cs pin.Output) *Device

Create a new Device to read from a MAX6675 thermocouple. Pins must be configured before use. Frequency for SPI should be 4.3MHz maximum.

func (*Device) Read

func (d *Device) Read() (float32, error)

Read and return the temperature in celsius

Jump to